summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--nuttx/arch/arm/src/lpc17xx/chip/lpc17_mcpwm.h2
-rw-r--r--nuttx/configs/zkit-arm-1769/src/up_adc.c2
-rw-r--r--nuttx/configs/zkit-arm-1769/src/up_dac.c1
-rw-r--r--nuttx/configs/zkit-arm-1769/src/up_lcd.c2
-rw-r--r--nuttx/configs/zkit-arm-1769/src/up_nsh.c3
-rw-r--r--nuttx/configs/zkit-arm-1769/src/up_usbmsc.c3
-rw-r--r--nuttx/configs/zkit-arm-1769/src/zkitarm_internal.h14
-rw-r--r--nuttx/include/assert.h15
-rw-r--r--nuttx/include/nuttx/net/net.h5
9 files changed, 32 insertions, 15 deletions
diff --git a/nuttx/arch/arm/src/lpc17xx/chip/lpc17_mcpwm.h b/nuttx/arch/arm/src/lpc17xx/chip/lpc17_mcpwm.h
index 6ec4a6b20..10abbd232 100644
--- a/nuttx/arch/arm/src/lpc17xx/chip/lpc17_mcpwm.h
+++ b/nuttx/arch/arm/src/lpc17xx/chip/lpc17_mcpwm.h
@@ -190,7 +190,7 @@
#define MCPWM_CAPCON_HNFCAP0 (1 << 21) /* Bit 21: Hardware noise filter */
#define MCPWM_CAPCON_HNFCAP1 (1 << 22) /* Bit 22: Hardware noise filter */
#define MCPWM_CAPCON_HNFCAP2 (1 << 23) /* Bit 23: Hardware noise filter */
- /* Bits 24-31: Reserved
+ /* Bits 24-31: Reserved */
/* Dead time register */
#define MCPWM_DT_DT0_SHIFT (0) /* Bits 0-9: Dead time for channel 0 */
diff --git a/nuttx/configs/zkit-arm-1769/src/up_adc.c b/nuttx/configs/zkit-arm-1769/src/up_adc.c
index 1e7b9b7da..b76cdfbc7 100644
--- a/nuttx/configs/zkit-arm-1769/src/up_adc.c
+++ b/nuttx/configs/zkit-arm-1769/src/up_adc.c
@@ -54,7 +54,7 @@
#include "chip.h"
#include "up_arch.h"
-#include "lpc17_pwm.h"
+#include "lpc17_adc.h"
#include "zkitarm_internal.h"
#ifdef CONFIG_ADC
diff --git a/nuttx/configs/zkit-arm-1769/src/up_dac.c b/nuttx/configs/zkit-arm-1769/src/up_dac.c
index a6f5db7ce..5d66c56f3 100644
--- a/nuttx/configs/zkit-arm-1769/src/up_dac.c
+++ b/nuttx/configs/zkit-arm-1769/src/up_dac.c
@@ -55,6 +55,7 @@
#include "up_internal.h"
#include "zkitarm_internal.h"
+#include "lpc17_dac.h"
#ifdef CONFIG_DAC
diff --git a/nuttx/configs/zkit-arm-1769/src/up_lcd.c b/nuttx/configs/zkit-arm-1769/src/up_lcd.c
index 3f34683f6..e29996b31 100644
--- a/nuttx/configs/zkit-arm-1769/src/up_lcd.c
+++ b/nuttx/configs/zkit-arm-1769/src/up_lcd.c
@@ -53,11 +53,13 @@
#include <nuttx/spi.h>
#include <nuttx/lcd/lcd.h>
#include <nuttx/lcd/st7567.h>
+#include <nuttx/arch.h>
#include "up_arch.h"
#include "up_internal.h"
#include "lpc17_gpio.h"
+#include "lpc17_ssp.h"
#include "zkitarm_internal.h"
#ifdef CONFIG_NX_LCDDRIVER
diff --git a/nuttx/configs/zkit-arm-1769/src/up_nsh.c b/nuttx/configs/zkit-arm-1769/src/up_nsh.c
index 78fddc035..63553e532 100644
--- a/nuttx/configs/zkit-arm-1769/src/up_nsh.c
+++ b/nuttx/configs/zkit-arm-1769/src/up_nsh.c
@@ -51,6 +51,7 @@
#include <nuttx/spi.h>
#include <nuttx/mmcsd.h>
+#include "lpc17_spi.h"
/****************************************************************************
* Pre-Processor Definitions
@@ -148,7 +149,7 @@ int nsh_archinitialize(void)
/* Get the SSP port */
- ssp = lpc17_sspinitialize(CONFIG_NSH_MMCSDSPIPORTNO);
+ ssp = lpc17_spiinitialize(CONFIG_NSH_MMCSDSPIPORTNO);
if (!ssp)
{
message("nsh_archinitialize: Failed to initialize SSP port %d\n",
diff --git a/nuttx/configs/zkit-arm-1769/src/up_usbmsc.c b/nuttx/configs/zkit-arm-1769/src/up_usbmsc.c
index 8873c39f4..60f3e2dc2 100644
--- a/nuttx/configs/zkit-arm-1769/src/up_usbmsc.c
+++ b/nuttx/configs/zkit-arm-1769/src/up_usbmsc.c
@@ -53,6 +53,9 @@
#include <nuttx/spi.h>
#include <nuttx/mmcsd.h>
+#include "lpc17_spi.h"
+#include "zkitarm_internal.h"
+
/****************************************************************************
* Pre-Processor Definitions
****************************************************************************/
diff --git a/nuttx/include/assert.h b/nuttx/include/assert.h
index 29eb7a4b3..2159ea868 100644
--- a/nuttx/include/assert.h
+++ b/nuttx/include/assert.h
@@ -47,14 +47,13 @@
* Pre-processor Definitions
****************************************************************************/
-/* Macro Name: ASSERT, ASSERTCODE, et al. */
-
-#undef ASSERT - Assert if the condition is not true
-#undef ASSERTCODE - Assert with an error code if the condition is not true
-#undef VERIFY - Assert if a function returns a negative value
-#undef DEBUGASSERT - Like ASSERT, but only if CONFIG_DEBUG is defined
-#undef DEBUGVERIFY - Like VERIFY, but only if CONFIG_DEBUG is defined
-#undef PANIC - Unconditional error with code
+/* Macro Name: ASSERT, VERIFY, et al. */
+
+#undef ASSERT /* Assert if the condition is not true */
+#undef VERIFY /* Assert if a function returns a negative value */
+#undef DEBUGASSERT /* Like ASSERT, but only if CONFIG_DEBUG is defined */
+#undef DEBUGVERIFY /* Like VERIFY, but only if CONFIG_DEBUG is defined */
+#undef PANIC /* Unconditional abort */
#ifdef CONFIG_HAVE_FILENAME
diff --git a/nuttx/include/nuttx/net/net.h b/nuttx/include/nuttx/net/net.h
index a7f8f0578..d9ba5b9f4 100644
--- a/nuttx/include/nuttx/net/net.h
+++ b/nuttx/include/nuttx/net/net.h
@@ -112,7 +112,7 @@ struct socketlist
/* Callback from netdev_foreach() */
-struct uip_driver_s; /* Forward reference. See nuttx/net/uip/uip-arch.h */
+struct uip_driver_s; /* Forward reference. Defined in nuttx/net/uip/uip-arch.h */
typedef int (*netdev_callback_t)(FAR struct uip_driver_s *dev, void *arg);
/****************************************************************************
@@ -172,6 +172,7 @@ int psock_close(FAR struct socket *psock);
/* net_close.c ***************************************************************/
/* Performs the bind() operation on a socket instance */
+struct sockaddr; /* Forward reference. Defined in nuttx/include/sys/socket.h */
int psock_bind(FAR struct socket *psock, FAR const struct sockaddr *addr,
socklen_t addrlen);
@@ -198,7 +199,7 @@ ssize_t psock_sendto(FAR struct socket *psock, FAR const void *buf,
/* recvfrom using the underlying socket structure */
ssize_t psock_recvfrom(FAR struct socket *psock, FAR void *buf, size_t len,
- int flags,FAR struct sockaddr *from,
+ int flags, FAR struct sockaddr *from,
FAR socklen_t *fromlen);
/* recv using the underlying socket structure */
diff --git a/nuttx/configs/zkit-arm-1769/src/zkitarm_internal.h b/nuttx/configs/zkit-arm-1769/src/zkitarm_internal.h
index b666c8387..6a4542c4b 100644
--- a/nuttx/configs/zkit-arm-1769/src/zkitarm_internal.h
+++ b/nuttx/configs/zkit-arm-1769/src/zkitarm_internal.h
@@ -145,7 +145,7 @@
#define ZKITARM_KEY4 (GPIO_INPUT | GPIO_FLOAT | GPIO_PORT1 | GPIO_PIN31)
#define ZKITARM_KEY5 (GPIO_INPUT | GPIO_FLOAT | GPIO_PORT2 | GPIO_PIN13)
-#define ZKITARM_INT_KEY5 (GPIO_INTBOTH | GPIO_FLOAT | GPIO_PORT2 | GPIO_PIN13)
+#define ZKITARM_INT_KEY5 (GPIO_INTFE | GPIO_FLOAT | GPIO_PORT2 | GPIO_PIN13)
#define ZKITARM_KEY5_IRQ LPC17_IRQ_P2p13
/* SD Slot
@@ -234,11 +234,21 @@
* Name: zkit_sspinitialize
*
* Description:
* Called to configure SPI chip select GPIO pins for the LPCXpresso board.
*
************************************************************************************/
void weak_function zkit_sspinitialize(void);
+/************************************************************************************
+ * Name: zkit_spinitialize
+ *
+ * Description:
+ * Called to configure SPI chip select GPIO pins for the ZKit-ARM-1769 board.
+ *
+ ************************************************************************************/
+
+void weak_function zkit_spiinitialize(void);
+
#endif /* __ASSEMBLY__ */
#endif /* _CONFIGS_ZKITARM_LPC1768_SRC_ZKITARM_INTERNAL_H */
@@ -234,11 +234,21 @@
*
* Description:
- * Called to configure SPI chip select GPIO pins for the LPCXpresso board.
+ * Called to configure SSP chip select GPIO pins for the ZKit-ARM-1769 board.
*
************************************************************************************/